DecimationFilter

Struct DecimationFilter 

pub struct DecimationFilter {
    pub filter: DecimationFilterType,
    pub item: Option<FilterItem>,
}
Available on crate feature processing only.

Fields

filter: DecimationFilterType

Type of decimation filter

item: Option<FilterItem>

Optional decimated item. When item is None, all data is to be decimated. When item is specified, only that subset is to be decimated.

Implementations

Source

impl DecimationFilter

pub fn duration(dt: Duration) -> Self

Builds a new Duration decimation filter

pub fn modulo(modulo: u32) -> Self

Builds new Modulo decimation filter

pub fn with_item(&self, item: FilterItem) -> Self

Adds targetted item to be decimated